@@ -1,4 +1,4 @@
-from .corpus import KoreanChatCorpus
+from .corpus import GenerationDataset, NsmcCorpus
 from .task import GenerationTask
 from .tokenizer import KoGPT2Tokenizer
 from .arguments import GenerationTrainArguments, GenerationDeployArguments
