@@ -22,7 +22,7 @@ REMOTE_DATA_MAP = {
     },
     "ner": {
         "train": {
-            "googledrive_file_id": "1Go8AWhli7KtBpOz3iloaDpwGbGqmMsBP",
+            "googledrive_file_id": "18DQMbMDADDGgHB8FHYhJ-6svKXx2Anu_",
             "fname": "train.txt",
         },
         "val": {
